from diagrams import Diagram
from diagrams.c4 import Person, System, SystemBoundary, Container, Database, Relationship

graph_attributes = {
    "resolution": "256",
    "margin": "-2",
    "splines": "spline",
}

def create_diagram():
    with Diagram(name="", filename="out/component", show=False, direction="TB", graph_attr=graph_attributes):
        openai_api = System("OpenAI API", external=True)
        inhouse_llm_api = System("InHouse LLM API", external=True)
        piccolodb = System("PiccoloDB", description="Provides access to DB over an API")

        with SystemBoundary("Chat service"):
            api_handler = Container("main.py", description="Handles API calls")
            openai_assistant = Container("OpenAI assistant")
            mixtral_assistant = Container("Mixtral assistant")

        api_handler >> Relationship("Makes calls against") >> openai_assistant
        api_handler >> Relationship("Uses for text to speech") >> openai_assistant
        api_handler >> Relationship("Makes calls against") >> mixtral_assistant
        api_handler >> Relationship("Gets recipes from") >> piccolodb
        openai_assistant >> Relationship("Uses") >> openai_api
        mixtral_assistant >> Relationship("Uses") >> inhouse_llm_api


if __name__ == '__main__':
    create_diagram()
