from diagrams import Diagram
from diagrams.c4 import Person, System, SystemBoundary, Container, Database, Relationship

graph_attributes = {
    "resolution": "256",
    "margin": "-2",
    "splines": "spline",
}

def create_diagram():
    with Diagram(name="", filename="out/container", show=False, direction="TB", graph_attr=graph_attributes):
        user = Person("User", description="A user of the Smart Eating platform")
        openai_api = System("OpenAI API", external=True)
        inhouse_llm_api = System("InHouse LLM API", external=True)

        with SystemBoundary("Smart Eating Platform"):
            web_frontend = Container("Webapp Frontend", description="The Chatbot UI is located in here", technology="React")
            web_backend = Container("Webapp Backend", technology="C#")
            piccolodb = Container("PiccoloDB", technology="Python", description="Provides access to DB over an API")
            chatbot_service = Container("ChatBot Service", technology="Python")
            db = Database("Database", technology="postgres")

        user >> Relationship("Interacts with") >> web_frontend
        web_frontend >> Relationship("Requests data from") >> web_backend
        web_backend >> Relationship("Sends requested data to") >> web_frontend
        web_backend >> Relationship("Requests data from") >> piccolodb
        piccolodb >> Relationship("Requests data from") >> db
        db >> Relationship("Returns requested data to") >> piccolodb
        piccolodb >> Relationship("Returns requested data to") >> web_backend
        web_backend >> Relationship("Makes request to") >> chatbot_service
        chatbot_service >> Relationship("Sends request to") >> openai_api
        openai_api >> Relationship("Returns processed request to") >> chatbot_service
        chatbot_service >> Relationship("Returns processed request to") >> web_backend
        chatbot_service >> Relationship("Requests data from") >> piccolodb
        piccolodb >> Relationship("Returns requested data to") >> chatbot_service
        chatbot_service >> Relationship("Sends request to") >> inhouse_llm_api
        inhouse_llm_api >> Relationship("Returns processed request to") >> chatbot_service


if __name__ == '__main__':
    create_diagram()
